pub enum BorderPosition {
Inset,
Center,
Outset,
}Expand description
Represents whether a border is inset, outset, or if it lays in the center.
Variants
Inset
An inset border. May overlap the contents of inside the shape.
Center
A border that is balanced between the inside and outside of the shape.
Outset
An outset border. May overlap the contents of outside the shape. This is the default behavior because it is usually what you would expect.