Module filter

Module filter 

Filters that can be applied on images.

Structs

Brightness
A brightness filter.
Mask
A filter which applies the given filter only to the given mask.

Traits

Filter
An image filter than can be lazily applied to an image or a filtered image.