RadialGradientCover

Enum RadialGradientCover 

pub enum RadialGradientCover {
    Stretch,
    Shortest,
    Longest,
}
How a radial gradient should cover its shape if the aspect ratio of the bounding box != 1.

Variants



Stretch

Stretch the gradient. This is the default behavior.



Shortest

Set the color stop at 1.0 to render at the end of the shortest side, in a way that shows the entire gradient.



Longest

Set the color stop at 1.0 to render at the end of the longest side, in a way that cuts off the gradient.