Implements the animated image and image sequence interface.
Structs
- Frame
- Represents a frame in an image sequence. It encloses an
Imageand extra metadata about the frame. - Image
Sequence - Represents a sequence of image frames such as an animated image.
Enums
- Disposal
Method - The method used to dispose a frame before transitioning to the next frame in an image sequence.
- Loop
Count - Determines how many times an image sequence should repeat itself, or if it should repeat infinitely.